@@ -5,7 +5,7 @@ package Bundle::SYP;
 use strict;
 use utf8;
 use warnings 'all';
-our $VERSION = '0.9'; # VERSION
+our $VERSION = '1.0'; # VERSION
 
 1;
 
@@ -21,7 +21,7 @@ Bundle::SYP - SYP's cozy environment
 
 =head1 VERSION
 
-version 0.9
+version 1.0
 
 =head1 SYNOPSIS
 
@@ -64,6 +64,8 @@ Daemon::Generic
 
 Data::Printer
 
+Data::Printer::Filter::URI
+
 DateTime::Format::Strptime
 
 Devel::NYTProf
@@ -134,6 +136,8 @@ MooseX::NonMoose
 
 Net::Curl
 
+Net::Whois::Raw
+
 Number::Format
 
 Perl::Critic
@@ -180,6 +184,8 @@ URI::sftp
 
 Unicode::CheckUTF8
 
+Web::Scraper
+
 WWW::Curl
 
 XML::Rabbit
